import { useState } from "react";
import React from "react";
import { createPortal } from "react-dom";
import { Button, Dialog, DialogActions, DialogContent, DialogContentText, DialogTitle } from "@material-ui/core";
import { useTranslation } from "react-i18next";

export type ConfirmProps = {
    children: (action: () => void) => React.ReactNode,
    title?: string,
    content?: React.ReactNode,
    onConfirm?: () => void,
    onCancel?: () => void,
}

export function Confirm({ children, title, content, onConfirm, onCancel }: ConfirmProps) {
    const [ open, setOpen ] = useState<boolean>(false);
    const { t } = useTranslation();

    const handleCancel = () => {
        setOpen(false);
        onCancel?.();
    }

    const handleConfirm = () => {
        setOpen(false);
        onConfirm?.();
    }

    return <>
        { children(() => { setOpen(true) }) }
        { createPortal(
            <Dialog open={ open } onClose={ handleCancel }>
                { title && <DialogTitle>{ title }</DialogTitle>}
                <DialogContent>
                    <DialogContentText>{ content || t('confirmation') }</DialogContentText>
                </DialogContent>
                <DialogActions>
                    <Button color="primary" variant="contained" autoFocus onClick={ handleConfirm }>{ t('confirm') }</Button>
                    <Button onClick={ handleCancel }>{ t('cancel') }</Button>
                </DialogActions>
            </Dialog>,
            document.getElementById("modals") as Element,
        ) }
    </>
}
